==> aroundme_0_6_6.zip: aroundme_0_6_6/aroundme/language/1/barnraiser_01/grp_create.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


$lang['section_create_group'] = 				"create a group";


//HEADER
$lang['hdr_group_setup_rules'] = 				"some simple rules";


//SUBMIT BUTTONS
$lang['sub_apply'] = 							"apply";
$lang['sub_hidden_group_radio'] = 				"create a hidden group";
$lang['sub_visible_group_radio'] = 				"create a visible group";
$lang['sub_create_group'] = 					"create your group";


//A HREF TAGS (links)
$lang['href_new_group'] =						"go to your new group now";


//BODY TEXT
$lang['txt_intro'] = 							"What to create a group?";
$lang['txt_intro_help'] = 						"Creating a group is easy. Just agree to the rules below and answer some simple questions. We will create all the defaults you need including groups rules and a group structure. Please remember to take a moment to see if their is already a group running with the same subject material and mission.";
$lang['txt_hidden_group_intro'] = 				"A hidden group is run by you and is hidden from the node.";
$lang['txt_visible_group_intro'] = 				"To create a visible group you have to either be a non for profit organisation and you have to run it under the terms of your articles or association or you agree to administrating the group and running yearly elections to elect a council and chair to oversee the group.";
$lang['txt_group_registration_type'] = 			"Membership registration type";
$lang['txt_group_registration_closed'] = 		"No member can join. Only you can add them.";
$lang['txt_group_registration_approved'] = 		"Any member of the node can apply, but you have to approve their membership";
$lang['txt_group_registration_automatic'] = 	"Any member can join without you needing to approve their application";
$lang['txt_age_from'] = 						"from age";
$lang['txt_age_to'] = 							"to age";
$lang['txt_age_any'] = 							"any";
$lang['txt_admin_note'] =						"Is there any other information you want to give to the administrator?";
$lang['txt_group_title'] = 						"What is the name of your group?";
$lang['txt_group_description'] = 				"Give a short description of your group.";
$lang['txt_group_language'] = 					"What language do you want the group contributions to be in?";
$lang['txt_group_age'] = 						"What is, if any the recommended participation age of the membership?";
$lang['txt_group_genre'] = 						"Select the genre that best describes your group.";
$lang['txt_note'] =								"Is there any other information you wish the administrator to know? If so, add it here.";
$lang['txt_group_completed_pending'] = 			"Thank you for applying to start a group. The group administrator will message you shortly.";
$lang['txt_group_completed'] = 					"Your group has been created. You will be taken to the privileges page where you can assign privileges to different membership roles.";
$lang['txt_group_tags'] = 						"Add up to 10 tags that describe your group (you can edit these at any time). <br />Format the words as comma separated text; for example: 'group, social software'.";

$lang['txt_group_setup_rules'] = 				"You can find a full introduction about groups, policy and structure within our support area.<br /><p>1. I agree that I will observe the laws of Sweden.<br />2. As part of that I am aware of the BBS act(1998:112) and how I must comply with it within 24 hours otherwise my group will be removed prior to compliance.</p>";
$lang['txt_group_hidden_rules'] = 				"These are the rules for hidden groups.";
$lang['txt_group_visible_rules'] = 				"These are the rules for visible groups.";

?>

==> aroundme_0_6_8.zip: aroundme_0_6_8/aroundme/language/1/barnraiser_01/grp_create.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


$lang['section_create_group'] = 				"create a group";


//HEADER
$lang['hdr_group_setup_rules'] = 				"some simple rules";


//SUBMIT BUTTONS
$lang['sub_apply'] = 							"apply";
$lang['sub_hidden_group_radio'] = 				"create a hidden group";
$lang['sub_visible_group_radio'] = 				"create a visible group";
$lang['sub_create_group'] = 					"create your group";


//A HREF TAGS (links)
$lang['href_new_group'] =						"go to your new group now";


//BODY TEXT
$lang['txt_intro'] = 							"What to create a group?";
$lang['txt_intro_help'] = 						"Creating a group is easy. Just agree to the rules below and answer some simple questions. We will create all the defaults you need including groups rules and a group structure. Please remember to take a moment to see if their is already a group running with the same subject material and mission.";
$lang['txt_hidden_group_intro'] = 				"A hidden group is run by you and is hidden from the node.";
$lang['txt_visible_group_intro'] = 				"To create a visible group you have to either be a non for profit organisation and you have to run it under the terms of your articles or association or you agree to administrating the group and running yearly elections to elect a council and chair to oversee the group.";
$lang['txt_group_registration_type'] = 			"Membership registration type";
$lang['txt_group_registration_closed'] = 		"No member can join. Only you can add them.";
$lang['txt_group_registration_approved'] = 		"Any member of the node can apply, but you have to approve their membership";
$lang['txt_group_registration_automatic'] = 	"Any member can join without you needing to approve their application";
$lang['txt_age_from'] = 						"from age";
$lang['txt_age_to'] = 							"to age";
$lang['txt_age_any'] = 							"any";
$lang['txt_admin_note'] =						"Is there any other information you want to give to the administrator?";
$lang['txt_group_title'] = 						"What is the name of your group?";
$lang['txt_group_description'] = 				"Give a short description of your group.";
$lang['txt_group_language'] = 					"What language do you want the group contributions to be in?";
$lang['txt_group_age'] = 						"What is, if any the recommended participation age of the membership?";
$lang['txt_group_genre'] = 						"Select the genre that best describes your group.";
$lang['txt_note'] =								"Is there any other information you wish the administrator to know? If so, add it here.";
$lang['txt_group_completed_pending'] = 			"Thank you for applying to start a group. The group administrator will message you shortly.";
$lang['txt_group_completed'] = 					"Your group has been created. You will be taken to the privileges page where you can assign privileges to different membership roles.";
$lang['txt_group_tags'] = 						"Add up to 10 tags that describe your group (you can edit these at any time). <br />Format the words as comma separated text; for example: 'group, social software'.";
$lang['txt_group_setup_rules'] = 				"You can find a full introduction about groups, policy and structure within our support area.<br /><p>1. I agree that I will observe the laws of Sweden.<br />2. As part of that I am aware of the BBS act(1998:112) and how I must comply with it within 24 hours otherwise my group will be removed prior to compliance.</p>";
$lang['txt_group_hidden_rules'] = 				"These are the rules for hidden groups.";
$lang['txt_group_visible_rules'] = 				"These are the rules for visible groups.";
$lang['txt_group_unix_title'] = 				"unix title";
$lang['txt_group_unix_title_hint'] = 			"A unix title is a lowercase name (a-z and 0-9 characters only) that is used to create a unique sub domain for you, like http://groupname.my-domain.org/. Leave it empty if you do not want one.";

?>
